<?php
/* TOP_COMMENT_START
 * Copyright (C) 2022, Levion Partners dba PulseCMS - All Rights Reserved
 *
 * This file is part of Pulse Core. It may be used by individuals or organizations generating less than $400,000 USD per year in revenue, free-of-charge. Individuals or organizations generating over $400,000 in annual revenue who continue to use Pulse Core after 90 days for non-evaluation and non-development use must purchase a paid license. 
 *
 * Proprietary
 * You may modify this source code for internal use. Resale or redistribution is prohibited.
 *
 * You can get the latest version at: https://pulsecms.com/
 *
 * Dated June 2023
 *
TOP_COMMENT_END */

namespace pulsecore\store\stat;

/**
 * stats item storage handler
 */
class Item extends Base implements \pulsecore\store\Item {
	
	/*
	 * the basename of the gallery
	 */
	protected $basename = false;
	
	/*
	 * the directory containing the gallery
	 */
	protected $directory = false;
	
	/*
	 * the item state
	 */
	protected $state = false;
	
	/*
	 * data that might be useful later - this is not stored on disk
	 */
	protected $utility = false;
	
	/*
	 * construct
	 */
	function __construct () {
		
		# state
		$this->state = new \stdClass();
		$this->state->lines = [];
		
		# utility
		$this->utility = new \stdClass();
		$this->utility->relative_url = '';
		
	}
	
	/*
	 * accessor
	 */
	public function __get ($name) {
		
		if (isset($this->state->{$name})) {
			return $this->state->{$name};
		}
		
		if (isset($this->utility->{$name})) {
			return $this->utility->{$name};
		}
		
		\pulsecore\invariant( false );
	}
	
	/*
	 * accessor
	 */
	public function __isset ($name) {
		
		if (isset($this->state->{$name})) {
			return true;
		}
		
		if (isset($this->utility->{$name})) {
			return true;
		}
		
		\pulsecore\invariant( false );
	}
	
	/*
	 * accessor
	 */
	public function __set ($name, $value) {
		
		if (isset($this->state->{$name})) {
			
			$this->state->{$name} = $value;
			
			if (\is_string($value)) {
				$this->state->{$name} = \trim($value);
			}
		}
		
		if (isset($this->utility->{$name})) {
			$this->utility->{$name} = $value;
		}
	}
	
	/*
	 * get the basename
	 * @return string
	 */
	public function get_basename () : string {
		return $this->basename;
	}
	
	/*
	 * extract gallery data from a filename - overwrite the current object state
	 * @param $filename string 
	 * @return void
	 */
	public function load (string $filename) /*: void*/ {
		
		\pulsecore\pre_condition(\strlen($filename) > 0);
		
		$this->basename  = \basename( $filename, '.txt' );
		$this->directory =  \dirname( $filename ); 
		
		$content = \file_get_contents($filename);
		
		$this->unpickle( $content );
	}
	
	/*
	 * cast to old format - this should be deprecated as soon as code is converted
	 * NB not used
	 * @return stdClass
	 */
	public function old_format () : \stdClass {
		
		\pulsecore\pre_condition( false );
		
		$result = new \stdClass();
		
		return $result;
	}
	
	/*
	 * pack object into a string
	 * @return string
	 */
	public function pickle () : string {
		
		$result = '';
		
		foreach ($this->state->lines as $key => $value) {
			
			$result .= $value->pickle();
			$result .= "\n";
		}
		
		return $result;
	}
	
	/*
	 * save gallery state to file
	 * @param string $filename
	 * @return void
	 */
	public function save (string $filename) /*: void*/ {
		
		\pulsecore\pre_condition(\strlen($filename) > 0);
		
		$content = $this->pickle();
		
		$status = \file_put_contents( $filename, $content );
		
		\pulsecore\invariant( $status !== false );
		
		# nuke caches
		$cache_manager = new \pulsecore\cache\Manager();
		$cache_pool    = $cache_manager->pool( \pulsecore\cache\Manager::DAY_1 );
		$cache_pool->nuke_tags( array('gallery_list') );
	}
	
	/*
	 * extract gallery data from a string - overwrite the current object state
	 * @param string $contentfile contents 
	 * @return void
	 */
	public function unpickle (string $content) /*: void*/ {
		
		\pulsecore\pre_condition(\strlen($content) >= 0);
		
		list($cleaned, $result) = \pulsecore\store\Base::extract( $content, $this->state );
		
		# extract rest of the data
		$data = \explode( "\n", $cleaned );
		
		$this->state->lines = [];
		
		foreach ($data as $line ) {
			
			$tmp = \trim($line);
			
			if (\strlen($tmp) > 0) {
				
				$datum_line = new \pulsecore\store\stat\Line();
				$datum_line->unpickle( $tmp );
				
				$this->state->lines[] = $datum_line;
			}
		}
	}
}
