<?php
/* TOP_COMMENT_START
 * Copyright (C) 2022, Levion Partners dba PulseCMS - All Rights Reserved
 *
 * This file is part of Pulse Core. It may be used by individuals or organizations generating less than $400,000 USD per year in revenue, free-of-charge. Individuals or organizations generating over $400,000 in annual revenue who continue to use Pulse Core after 90 days for non-evaluation and non-development use must purchase a paid license. 
 *
 * Proprietary
 * You may modify this source code for internal use. Resale or redistribution is prohibited.
 *
 * You can get the latest version at: https://pulsecms.com/
 *
 * Dated June 2023
 *
TOP_COMMENT_END */

namespace pulsecore\tags;

require_once (PULSE_BASE_DIR . '/pulsecore/wedge/tag_helper.php');

/**
 * block tag
 */
class Block extends Base {
	
	/*
	 * execute a block tag
	 * @param array $tag_runner_context Extra content to provide to tags
	 * @param string $tag_content Optional string with the between opening and closing tag content
	 * @return string
	 */
	public static function execute_tag (array $tag_vars, array $tag_runner_context = array(), string $tag_content = '') : string {
		
		\pulsecore\pre_condition(         isset($tag_vars['block_name']) );
		\pulsecore\pre_condition(    \is_string($tag_vars['block_name']) );
		\pulsecore\pre_condition( \strlen(\trim($tag_vars['block_name'])) > 0 );
		
		$tag = new \pulsecore\tags\Block();
		
		$result = $tag->generate_html(
			array('block_name' => $tag_vars['block_name']),
			$tag_runner_context,
			$tag_content
		);
		
		return $result;
	}
	
	/*
	 * generate html
	 * @param array $params Array of named arguments
	 * @param array $tag_runner_context Extra content to provide to tags
	 * @param string $tag_content Optional string with the between opening and closing tag content
	 * @return string
	 */
	public function generate_html (array $params = array(), array $tag_runner_context = array(), string $tag_content = '') : string {
		
		\pulsecore\pre_condition(      isset($tag_content) );
		\pulsecore\pre_condition( \is_string($tag_content) );
		
		$arguments = \array_merge( array(), $params );
		
		\pulsecore\pre_condition(         isset($arguments['block_name']) );
		\pulsecore\pre_condition(    \is_string($arguments['block_name']) );
		\pulsecore\pre_condition( \strlen(\trim($arguments['block_name'])) > 0 );
		
		$block_name = $arguments['block_name'];
		
		$block_name = \pulsecore\filter\item_url( $block_name );
		
		$filename = \pulsecore\get_configs()->dir_content . "/blocks/{$block_name}.txt";
		
		$filename_draft_mode = \dirname($filename) . '/draft-' . \basename($filename);
		
		# handle draft mode
		if (\file_exists($filename_draft_mode)) {
			return '';
		}
		
		# trap missing filename error
		if (!\file_exists($filename)) {
			return "(!!&#x2620; {$block_name} &#x2620;!!)";
		}
		
		# process
		$datum_block = new \pulsecore\store\block\Item();
		$datum_block->load( $filename );
		
		$result = $datum_block->html;
		
		# access control for user groups and logged in members
		if (\pulsecore\acl_role\test_logged_in()) {
			if (\pulsecore\acl_role\user_group_test_resource_controlled("blocks/{$block_name}")) {
				
				$allow_access = false;
				
				# admins and editors always have access
				$allow_access = ($allow_access or \pulsecore\acl_role\is_administrator() or \pulsecore\acl_role\is_editor());
				
				# check logged in user permissions
				if ((!$allow_access) and \pulsecore\acl_role\test_logged_in()) {
					$allow_access = ($allow_access or \pulsecore\acl_role\user_group_test_user_allowed("blocks/{$block_name}", 'r', $_SESSION['user_group_list']));
				}
				
				# skip block if no access allowed
				if (!$allow_access) {
					return '';
				}
			}
		}
		
		# special case home/home - handle front_page_display variable
		$result = \pulsecore\wedge\tag_helper\block__block( $block_name, $result );
		
		# expand tags in the the content
		$result = \pulsecore\tag_runner\expand(
			$result,
			\array_merge($tag_runner_context, array())
		);
		
		# wrap
		# $result = "<div class=\"tag-block\">{$result}</div>\n";
		
		# parsedown
		if (isset($GLOBALS['parsedown'])) {
			$result = $GLOBALS['parsedown']->text($result);
		}
		
		# inline edit
		if (\pulsecore\acl_role\can_edit_resource( \pulsecore\wedge\config\get_json_configs()->json->navigation_options->logged_in_menu )) {
			$view_helper_inline_edit = new \pulsecore\view\helper\InlineEdit();
			$result = $view_helper_inline_edit->render( array($block_name, 'block', $result) );
		}
		
		return $result;
	}
}
