<?php
/* TOP_COMMENT_START
 * Copyright (C) 2022, Levion Partners dba PulseCMS - All Rights Reserved
 *
 * This file is part of Pulse Core. It may be used by individuals or organizations generating less than $400,000 USD per year in revenue, free-of-charge. Individuals or organizations generating over $400,000 in annual revenue who continue to use Pulse Core after 90 days for non-evaluation and non-development use must purchase a paid license. 
 *
 * Proprietary
 * You may modify this source code for internal use. Resale or redistribution is prohibited.
 *
 * You can get the latest version at: https://pulsecms.com/
 *
 * Dated June 2023
 *
TOP_COMMENT_END */

namespace pulsecore\tags;

require_once (PULSE_BASE_DIR . '/pulsecore/src/acl_role.php');

/**
 * date tag
 */
class BlogItemDate extends Base {
	
	/*
	 * default date format
	 */
	const FORMAT_DEFAULT = 'Y-m-d';
	
	/*
	 * the format the date is stored in
	 */
	const FORMAT_STORAGE = 'm-d-Y';
	
	/*
	 * generate html
	 * @param string $arg
	 * @param string $format
	 * @return string
	 */
	public static function format_date (string $arg, string $format) : string {
		
		\pulsecore\pre_condition(         isset($arg) );
		\pulsecore\pre_condition(    \is_string($arg) );
		\pulsecore\pre_condition( \strlen(\trim($arg)) > 0 );
		
		\pulsecore\pre_condition(         isset($format) );
		\pulsecore\pre_condition(    \is_string($format) );
		\pulsecore\pre_condition( \strlen(\trim($format)) > 0 );
		
		# handle MM-DD-YYYY format
		$result = \pulsecore\store\blog\Item::parse_date( $arg );
		
		$result = \pulsecore\utf8_date_format( $format, $result->getTimestamp() );
		
		return $result;
	}
	
	/*
	 * generate html
	 * @param array $params Array of named arguments
	 * @param array $tag_runner_context Extra content to provide to tags
	 * @param string $tag_content Optional string with the between opening and closing tag content
	 * @return string
	 */
	public function generate_html (array $params = array(), array $tag_runner_context = array(), string $tag_content = '') : string {
		
		\pulsecore\pre_condition(      isset($tag_content) );
		\pulsecore\pre_condition( \is_string($tag_content) );
		
		$arguments = \array_merge( array('format' => \pulsecore\store\blog\Item::DATE_FORMAT_DEFAULT), $params );
		
		\pulsecore\pre_condition( isset($arguments['blog_item']) );
		\pulsecore\pre_condition(       $arguments['blog_item'] instanceof \pulsecore\store\blog\Item );
		
		\pulsecore\pre_condition(         isset($arguments['format']) );
		\pulsecore\pre_condition(    \is_string($arguments['format']) );
		\pulsecore\pre_condition( \strlen(\trim($arguments['format'])) > 0 );
		
		$format = \trim($arguments['format']);
		
		$result = BlogItemDate::format_date( $arguments['blog_item']->date, $format );
		
		# wrap
		$result = "<p class=\"blog-item-grid-item tag-blog-item-date blog-date blog-entry-date\">{$result}</p>\n";
		
		return $result;
	}
}
