<?php
/* TOP_COMMENT_START
 * Copyright (C) 2022, Levion Partners dba PulseCMS - All Rights Reserved
 *
 * This file is part of Pulse Core. It may be used by individuals or organizations generating less than $400,000 USD per year in revenue, free-of-charge. Individuals or organizations generating over $400,000 in annual revenue who continue to use Pulse Core after 90 days for non-evaluation and non-development use must purchase a paid license. 
 *
 * Proprietary
 * You may modify this source code for internal use. Resale or redistribution is prohibited.
 *
 * You can get the latest version at: https://pulsecms.com/
 *
 * Dated June 2023
 *
TOP_COMMENT_END */

namespace pulsecore\tags;

require_once (PULSE_BASE_DIR . '/pulsecore/src/acl_role.php');

/**
 * blog item featured image (if any)
 */
class BlogItemFeaturedImage extends Base {
	
	/*
	 * generate html
	 * @param array $params Array of named arguments
	 * @param array $tag_runner_context Extra content to provide to tags
	 * @param string $tag_content Optional string with the between opening and closing tag content
	 * @return string
	 */
	public function generate_html (array $params = [], array $tag_runner_context = [], string $tag_content = '') : string {
		
		# logic
		$logic_featured_image = new \pulsecore\logic\FeaturedImage();
		
		\pulsecore\pre_condition(      isset($tag_content) );
		\pulsecore\pre_condition( \is_string($tag_content) );
		
		$arguments = \array_merge( [], $params );
		
		\pulsecore\pre_condition( isset($arguments['blog_item']) );
		\pulsecore\pre_condition(       $arguments['blog_item'] instanceof \pulsecore\store\blog\Item );
		
		$probe = \trim( $arguments['blog_item']->id );
		
		$result = $logic_featured_image->process(
			[
				'blog_id'            => $probe,
				'blog_item_location' => $arguments['blog_item']->location
			]
		);
		
		if ($result->url !== false) {
			
			$result = "<img alt=\"teaser-image\" src=\"{$result->url}\" />";
		} else {
			# noop
			$result = '';
		}
		
		# wrap
		$result = "<div class=\"blog-item-grid-item tag-blog-item-featured-image\">{$result}</div>\n";
		
		return $result;
	}
}
