<?php
/* TOP_COMMENT_START
 * Copyright (C) 2022, Levion Partners dba PulseCMS - All Rights Reserved
 *
 * This file is part of Pulse Core. It may be used by individuals or organizations generating less than $400,000 USD per year in revenue, free-of-charge. Individuals or organizations generating over $400,000 in annual revenue who continue to use Pulse Core after 90 days for non-evaluation and non-development use must purchase a paid license. 
 *
 * Proprietary
 * You may modify this source code for internal use. Resale or redistribution is prohibited.
 *
 * You can get the latest version at: https://pulsecms.com/
 *
 * Dated June 2023
 *
TOP_COMMENT_END */

namespace pulsecore\tags;

/**
 * show the picture
 */
class Picture extends Base {
	
	/*
	 * execute a block tag
	 * @param array $tag_runner_context Extra content to provide to tags
	 * @param string $tag_content Optional string with the between opening and closing tag content
	 * @return string
	 */
	public static function execute_tag (array $tag_vars, array $tag_runner_context = [], string $tag_content = '') : string {
		
		\pulsecore\pre_condition(         isset($tag_vars['alt']) );
		\pulsecore\pre_condition(    \is_string($tag_vars['alt']) );
		\pulsecore\pre_condition( \strlen(\trim($tag_vars['alt'])) >= 0 );
		
		\pulsecore\pre_condition(         isset($tag_vars['element_height']) );
		\pulsecore\pre_condition(    \is_string($tag_vars['element_height']) );
		\pulsecore\pre_condition( \strlen(\trim($tag_vars['element_height'])) >= 0 );
		
		\pulsecore\pre_condition(         isset($tag_vars['element_width']) );
		\pulsecore\pre_condition(    \is_string($tag_vars['element_width']) );
		\pulsecore\pre_condition( \strlen(\trim($tag_vars['element_width'])) >= 0 );
		
		\pulsecore\pre_condition(         isset($tag_vars['src']) );
		\pulsecore\pre_condition(    \is_string($tag_vars['src']) );
		\pulsecore\pre_condition( \strlen(\trim($tag_vars['src'])) > 0 );
		
		$tag = new \pulsecore\tags\Picture();
		
		$result = $tag->generate_html(
			array(
				'src' => $tag_vars['src'],
				'alt' => $tag_vars['alt'],
				
				'element_width'  => (isset($tag_vars['element_width'])  ? $tag_vars['element_width']  : ""),
				'element_height' => (isset($tag_vars['element_height']) ? $tag_vars['element_height'] : "")
			),
			$tag_runner_context,
			$tag_content
		);
		
		return $result;
	}
	
	/**
	 * generate html
	 * @param array $params Array of named arguments
	 * @param array $tag_runner_context Extra content to provide to tags
	 * @param string $tag_content Optional string with the between opening and closing tag content
	 * @return string
	 */
	public function generate_html( array $params = [], array $tag_runner_context = [], string $tag_content = '') : string {
		
		# merge in defaults
		$arguments = \array_merge(
			[
				'alt'            => '',
				'element_width'  => '',
				'element_height' => '',
				'src'            => '',
			],
			$params
		);
		
		# safety
		\pulsecore\pre_condition(         isset($arguments['alt']) );
		\pulsecore\pre_condition(    \is_string($arguments['alt']) );
		\pulsecore\pre_condition( \strlen(\trim($arguments['alt'])) >= 0 );
		
		\pulsecore\pre_condition(         isset($arguments['element_height']) );
		\pulsecore\pre_condition(    \is_string($arguments['element_height']) );
		\pulsecore\pre_condition( \strlen(\trim($arguments['element_height'])) >= 0 );
		
		\pulsecore\pre_condition(         isset($arguments['element_width']) );
		\pulsecore\pre_condition(    \is_string($arguments['element_width']) );
		\pulsecore\pre_condition( \strlen(\trim($arguments['element_width'])) >= 0 );
		
		\pulsecore\pre_condition(         isset($arguments['src']) );
		\pulsecore\pre_condition(    \is_string($arguments['src']) );
		\pulsecore\pre_condition( \strlen(\trim($arguments['src'])) > 0 );
		
		# extract
		$alt            = $arguments['alt'];
		$element_width  = $arguments['element_width'];
		$element_height = $arguments['element_width'];
		$src            = $arguments['src'];
		
		# filter
		$alt            = \trim($alt, '"' );
		$element_width  = \trim($element_width, '"' );
		$element_height = \trim($element_width, '"' );
		$src            = \trim($src, '"' );
		
		# validate
		# none
		
		$result = '';
		
		# access control for user groups and logged in members
		if (\pulsecore\acl_role\test_logged_in()) {
			
			$resource_name = explode( '/media/', $source );
			
			if (isset($resource[1])) {
					
				$resource_name = 'media/' . $resource[1];
				$resource_name = \ltrim($resource_name, '/');
				
				if (\pulsecore\acl_role\user_group_test_resource_controlled($resource_name)) {
					
					$allow_access = false;
					
					# admins and editors always have access
					$allow_access = ($allow_access or \pulsecore\acl_role\is_administrator() or \pulsecore\acl_role\is_editor());
					
					# check logged in user permissions
					if ((!$allow_access) and \pulsecore\acl_role\test_logged_in()) {
						$allow_access = ($allow_access or \pulsecore\acl_role\user_group_test_user_allowed($resource_name, 'r', $_SESSION['user_group_list']));
					}
					
					# skip block if no access allowed
					if (!$allow_access) {
						return '';
					}
				}
			}
		}
		
		# HTML
		$attr_alt    = (\strlen($alt) > 0)            ?    "alt=\"{$alt}\""            : '';
		$attr_width  = (\strlen($element_width)  > 0) ?  "width=\"{$element_width}\""  : '';
		$attr_height = (\strlen($element_height) > 0) ? "height=\"{$element_height}\"" : '';
		
		$result .=<<<EOD
<picture>
	<img {$attr_alt} src="{$src}" {$attr_width} {$attr_height} />
</picture>

EOD;
		
		$result = \trim( $result );
		
		return $result;
	}
}
