<?php
/* TOP_COMMENT_START
 * Copyright (C) 2022, Levion Partners dba PulseCMS - All Rights Reserved
 *
 * This file is part of Pulse Core. It may be used by individuals or organizations generating less than $400,000 USD per year in revenue, free-of-charge. Individuals or organizations generating over $400,000 in annual revenue who continue to use Pulse Core after 90 days for non-evaluation and non-development use must purchase a paid license. 
 *
 * Proprietary
 * You may modify this source code for internal use. Resale or redistribution is prohibited.
 *
 * You can get the latest version at: https://pulsecms.com/
 *
 * Dated June 2023
 *
TOP_COMMENT_END */

namespace pulsecore\wedge\block\storage;

require_once (PULSE_BASE_DIR . '/pulsecore/bootstrap.php');

/**
 * inject the JSON configs from the config file
 * \param $content string The old style content
 * \param $expanded stdClass The new content to add
 * \return string
 */
function inject( $content, \stdClass $expanded ) {
	
	$result = \pulsecore\store\Base::inject( $content, $expanded );
	
	return $result;
}

/**
 * load a block file
 * \param $filename string
 * \param $location string The block file location
 * \return stdClass object
 */
function load_block_file( $filename, $location = '' ) {
	
	\pulsecore\pre_condition(      isset($filename) );
	\pulsecore\pre_condition( \is_string($filename) );
	\pulsecore\pre_condition(    \strlen($filename) > 0);
	\pulsecore\pre_condition(   \is_file($filename) );
	
	\pulsecore\pre_condition(      isset($location) );
	\pulsecore\pre_condition( \is_string($location) );
	\pulsecore\pre_condition(    \strlen($location) >= 0);
			
	$content = \file_get_contents($filename);
	
	$result = parse($content, $location);
	
	return $result;
}

/**
 * list all the blocks - recursing into sub directories too
 * \param $directory string
 * \param $location string The block file location
 * \return array of packed block objects
 */
function list_blocks( $directory, $location = '' ) {
	
	\pulsecore\pre_condition(      isset($directory) );
	\pulsecore\pre_condition( \is_string($directory) );
	\pulsecore\pre_condition(    \strlen($directory) > 0);
	
	\pulsecore\pre_condition(      isset($location) );
	\pulsecore\pre_condition( \is_string($location) );
	\pulsecore\pre_condition(    \strlen($location) >= 0);
	
	$result = array();
	
	$items = \glob( $directory . '/*' );
	
	foreach ($items as $value) {
		
		$lll = (\strlen($location) == 0) ? \basename($directory) : $location;
		$lll = $lll . '/' . \basename($value);
		
		#block
		if (\is_file($value) and (\stripos($value, '.txt') > 0)) {
			$result[] = load_block_file($value, $lll);
		}
		
		#directory
		if (\is_dir($value)) {
			$result = \array_merge( $result, list_blocks($value, $lll) );
		}
	}
	
	return $result;
}

/**
 * factory for creating the block storage object
 * \param $location string The block file location
 * \return stdClass object
 */
function make_store( $location = '' ) {
	
	$result  = new \stdClass();
	$result->html         = '';
	$result->location     = $location;
	$result->relative_url = '';
	
	return $result;
}

/**
 * parse the block storage file data
 * extract the new blog data
 * \param $content string (sometimes is false)
 * \param $location string The block file location
 * \return array of the cleaned data and the extracted new data
 */
function parse( $content, $location = '' ) {
	
	$ddd = make_store( $location );
	
	list($cleaned, $result) = \pulsecore\store\Base::extract( $content, $ddd );
	
	return array($cleaned, $result);
}

